KvCommand

Enum KvCommand 

pub enum KvCommand {
    Get {
        key: String,
    },
    Put {
        key: String,
        value: String,
    },
    Delete {
        key: String,
    },
    List {
        prefix: Option<String>,
    },
    Search {
        mode: KvSearchMode,
        pattern: String,
        pattern_hex: bool,
        cursor_hex: Option<String>,
        page_size: usize,
        scan_budget: usize,
        max_bytes: usize,
    },
    Txn(KvTxnCommand),
}
KV subcommands

Variants



Get

Get a value by key

Fields

key: String

The key to retrieve



Put

Put a key-value pair

Fields

key: String

The key to set

value: String

The value to store



Delete

Delete a key

Fields

key: String

The key to delete



List

List keys with optional prefix

Fields

prefix: Option<String>

Filter keys by prefix



Search

Search opaque key bytes with an explicit bounded pattern mode

Fields

mode: KvSearchMode

Matching mode

pattern: String

Pattern text, or hexadecimal bytes with –pattern-hex

pattern_hex: bool

Decode the glob pattern as hexadecimal bytes

cursor_hex: Option<String>

Exclusive prior-page cursor encoded as hexadecimal bytes

page_size: usize

Maximum entries returned by this page

scan_budget: usize

Maximum candidate keys inspected by this page

max_bytes: usize

Maximum combined key and value bytes returned by this page



Txn(KvTxnCommand)

Transaction operations