pub enum RoutingReportFormat {
Human,
Json,
}Expand description
Requested format for the distributed-read routing report. The report is emitted by the later output adapter and is intentionally separate from query stdout formats.
Variants