Module server

Module server 

Server management commands.

Functions

execute_remote
Execute a server management command against a remote server.
execute_remote_tui
execute_remote_with_format
Execute a server management command with the requested non-TUI output format. Existing callers retain table output through execute_remote.