pub async fn execute_remote<W: Write>(
client: &HttpClient,
cmd: &ServerCommand,
writer: &mut W,
quiet: bool,
) -> Result<()>Expand description
Execute a server management command against a remote server.
pub async fn execute_remote<W: Write>(
client: &HttpClient,
cmd: &ServerCommand,
writer: &mut W,
quiet: bool,
) -> Result<()>Execute a server management command against a remote server.