Server management commands.
Functions
- execute_
remote - Execute a server management command against a remote server.
- execute_
remote_ tui - execute_
remote_ with_ format - Execute a server management command with the requested non-TUI output
format. Existing callers retain table output through
execute_remote.