pub fn setup_signal_handler() -> Result<Arc<AtomicBool>>Expand description
Set up the Ctrl-C signal handler.
This function sets up a handler that will set the INTERRUPTED flag when the user presses Ctrl-C. The handler can be called multiple times; only the first call will set up the handler.
Returns
A reference to the interrupted flag for monitoring.